data.alloc: Allocate data To calculate the stratum sample sizes (nh) for...

View source: R/data.alloc.R

data.allocR Documentation

Allocate data To calculate the stratum sample sizes (nh) for a fixed sample size (n) directly based on the data

Description

Allocate data To calculate the stratum sample sizes (nh) for a fixed sample size (n) directly based on the data

Usage

data.alloc(data, my_env)

Arguments

data

Input dataset.

my_env

Environment object.

Value

...

Uses OSB to compute stratum weights (Wh), sample variances (Vh from data), and Neyman allocations (nh). Builds the summary table once at the end.


stratifyR documentation built on Sept. 10, 2026, 5:07 p.m.