distr.root: Calculate the objective function value for a given (d, y)...

View source: R/distr.root.R

distr.rootR Documentation

Calculate the objective function value for a given (d, y) under a hypothesized distribution (scaled-data formulation)

Description

Used by the DP recurrences in the "distribution-known" pathway. All distribution parameters are interpreted on the "scaled" axis (initval .. initval+dist), consistent with 'strata.distr()'.

Usage

distr.root(d, y, c, my_env)

Arguments

d

numeric: remaining distance/range on the (scaled) axis

y

numeric: width of the first stratum on the (scaled) axis

c

numeric: per stratum cost multiplier (Ch[k])

my_env

environment: holds distribution name, scaled parameters, and scaling constants ('initval', 'maxval', etc.)

Value

numeric: sqrt(objective) or -1 if branch is infeasible/invalid

Author(s)

Karuna Reddy <karuna.reddy@auckland.ac.nz>
MGM Khan <khan_mg@usp.ac.fj>


stratifyR documentation built on Sept. 10, 2026, 5:07 p.m.