erf: To calculate the error for a normal variable

View source: R/erf.R

erfR Documentation

To calculate the error for a normal variable

Description

This function calculates the value of the error according to the normally distributed variable using the idea presented in Abramowitz and Stegun (2011)

Usage

erf(x)

Arguments

x

The data that is provided

Value

Gives the error for a normal variable

Author(s)

Karuna Reddy <karuna.reddy@auckland.ac.nz>
MGM Khan <khan_mg@usp.ac.fj>


stratifyR documentation built on Sept. 10, 2026, 5:07 p.m.