Learn R Programming

stratifyR (version 2.0-1)

data.alloc: Allocate data To calculate the stratum sample sizes (nh) for a fixed sample size (n) directly based on the data

Description

Allocate data To calculate the stratum sample sizes (nh) for a fixed sample size (n) directly based on the data

Usage

data.alloc(data, my_env)

Value

...

Uses OSB to compute stratum weights (Wh), sample variances (Vh from data), and Neyman allocations (nh). Builds the summary table once at the end.

Arguments

data

Input dataset.

my_env

Environment object.